@@ -145,6 +145,7 @@ class StreamGobbler implements Runnable {
  *          28/04/11 FIX 1794 sequencelength unknown
  *          08/06/12 Add check option
  *          12/06/12 FIX 2162 If maxlength=0, set it to sequence size
+ *          04/10/13 FIX 2242 Error with overlap
  */
 public class Logol {
 
@@ -1760,7 +1761,7 @@ private static void clean(Vector<String> jobFiles) {
 			String output = Constants.LOGOLVARAFTER+LogolUtils.getPredicateOutput(mod.predicate);
 			data+= ",[Errors,Indel],Output) :- " + mod.predicate + ", Output="+ output;
 
-			data+= ","+mod.name.toUpperCase()+"="+LogolUtils.getSavedVariables(mod.predicate,-1,mod.name);
+			data+= ","+mod.name.toUpperCase()+"="+LogolUtils.getAllSavedVariables(mod.predicate,-1,mod.name);
 			
 			data+= ","+mod.name.toUpperCase()+"_"+Constants.POSTPONED+"="+LogolVariable.getPostponedVariableList(mod.name);
 			
@@ -1799,7 +1800,8 @@ private static void clean(Vector<String> jobFiles) {
 				 
 		data+="\t!,\n";
 		// Call the models and get the variable references as result. Each match will be written to file OutFile		
-		data+="\tquery(Res)\n";						
+		//data+="\tcatch(query(Res),Err,format('ERROR: An error occured during execution\n',[]))\n";						
+		data+="\tquery(Res)\n";
 		data+=".\n";		
 		data+="runtime_entry(Res):-\n";	
 		data+="\tprolog_flag('argv',Args),nth0(0,Args,File),\n";
