@@ -565,6 +565,33 @@ public class GrammarTest {
 		}
 		
 	}		
+
+	@Test
+	public void testComment2() {
+		// validate comment lines, takes same search than testComment
+		init();
+		
+		Vector<String[]> result = new Vector<String[]>();
+		result.add(new String[] {"LogolVAR_1","4","6"});
+		result.add(new String[] {"LogolVAR_2","7","10"});
+		result.add(new String[] {"LogolVAR_3","11","14"});
+		
+		execute("comment2.logol");
+		
+		try {
+			checkResult(result,0);
+		} catch (ParserConfigurationException e) {
+			fail(e.getMessage());
+		} catch (SAXException e) {
+			fail(e.getMessage());
+		} catch (IOException e) {
+			fail(e.getMessage());
+		} catch (TransformerException e) {
+			fail(e.getMessage());
+		}
+		
+	}	
+	
 	
 	 @Test
 	 public void testCostPostpone(){
@@ -1980,7 +2007,7 @@ public class GrammarTest {
 		}
 		
 		@Test
-		public void test2244() {
+		public void test2234() {
 			
 			init();
 			
@@ -2024,4 +2051,95 @@ public class GrammarTest {
 			}			
 		}
 		
+		@Test
+		public void test2242() {
+			
+			init();
+			
+			Vector<String[]> result = new Vector<String[]>();
+			result.add(new String[] {"LogolVAR_1","9","14"});
+			result.add(new String[] {"LogolVAR_2","15","15"});
+			result.add(new String[] {"LogolVAR_3","16","16"});
+			execute("2242.fasta","2242.logol");
+			
+			try {
+				checkResult(result,0);
+			} catch (ParserConfigurationException e) {
+				fail(e.getMessage());
+			} catch (SAXException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			} catch (TransformerException e) {
+				fail(e.getMessage());
+			}			
+		}	
+
+		@Test
+		public void test2243() {
+			
+			init();
+			
+			Vector<String[]> result = new Vector<String[]>();
+			result.add(new String[] {"LogolVAR_1","3","6"});
+			execute("2243.fasta","2243.logol");
+			
+			try {
+				checkResult(result,0);
+			} catch (ParserConfigurationException e) {
+				fail(e.getMessage());
+			} catch (SAXException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			} catch (TransformerException e) {
+				fail(e.getMessage());
+			}			
+		}
+		
+		@Test
+		public void test2244() {
+			
+			init();
+			
+			Vector<String[]> result = new Vector<String[]>();
+			result.add(new String[] {"LogolVAR_1","7","8"});
+			execute("test.fasta","fix2244.logol");
+			
+			try {
+				checkResult(result,0);
+			} catch (ParserConfigurationException e) {
+				fail(e.getMessage());
+			} catch (SAXException e) {
+				fail(e.getMessage());
+			} catch (IOException e) {
+				fail(e.getMessage());
+			} catch (TransformerException e) {
+				fail(e.getMessage());
+			}			
+		}
+		
+        /*
+        @Test
+        public void testindel() {
+
+            init();
+
+            Vector<String[]> result = new Vector<String[]>();
+            result.add(new String[] {"LogolVAR_1","5","5"});
+            execute("indel.fasta","indel.logol");
+
+            try {
+                checkResult(result,0);
+            } catch (ParserConfigurationException e) {
+                fail(e.getMessage());
+            } catch (SAXException e) {
+                fail(e.getMessage());
+            } catch (IOException e) {
+                fail(e.getMessage());
+            } catch (TransformerException e) {
+                fail(e.getMessage());
+            }
+       } */
+		
 }
